# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/matching_function.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import matching_function_context_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_matching__function__context__type__pb2
from google.ads.google_ads.v1.proto.enums import matching_function_operator_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_matching__function__operator__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/matching_function.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\025MatchingFunctionProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n<google/ads/googleads_v1/proto/common/matching_function.proto\x12\x1egoogle.ads.googleads.v1.common\x1aHgoogle/ads/googleads_v1/proto/enums/matching_function_context_type.proto\x1a\x44google/ads/googleads_v1/proto/enums/matching_function_operator.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xb2\x02\n\x10MatchingFunction\x12\x35\n\x0f\x66unction_string\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x66\n\x08operator\x18\x04 \x01(\x0e\x32T.google.ads.googleads.v1.enums.MatchingFunctionOperatorEnum.MatchingFunctionOperator\x12>\n\rleft_operands\x18\x02 \x03(\x0b\x32\'.google.ads.googleads.v1.common.Operand\x12?\n\x0eright_operands\x18\x03 \x03(\x0b\x32\'.google.ads.googleads.v1.common.Operand\"\xfe\x07\n\x07Operand\x12S\n\x10\x63onstant_operand\x18\x01 \x01(\x0b\x32\x37.google.ads.googleads.v1.common.Operand.ConstantOperandH\x00\x12^\n\x16\x66\x65\x65\x64_attribute_operand\x18\x02 \x01(\x0b\x32<.google.ads.googleads.v1.common.Operand.FeedAttributeOperandH\x00\x12S\n\x10\x66unction_operand\x18\x03 \x01(\x0b\x32\x37.google.ads.googleads.v1.common.Operand.FunctionOperandH\x00\x12`\n\x17request_context_operand\x18\x04 \x01(\x0b\x32=.google.ads.googleads.v1.common.Operand.RequestContextOperandH\x00\x1a\xff\x01\n\x0f\x43onstantOperand\x12\x34\n\x0cstring_value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12\x31\n\nlong_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x00\x12\x33\n\rboolean_value\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x12\x34\n\x0c\x64ouble_value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueH\x00\x42\x18\n\x16\x63onstant_operand_value\x1a|\n\x14\x46\x65\x65\x64\x41ttributeOperand\x12,\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11\x66\x65\x65\x64_attribute_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a^\n\x0f\x46unctionOperand\x12K\n\x11matching_function\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v1.common.MatchingFunction\x1a\x89\x01\n\x15RequestContextOperand\x12p\n\x0c\x63ontext_type\x18\x01 \x01(\x0e\x32Z.google.ads.googleads.v1.enums.MatchingFunctionContextTypeEnum.MatchingFunctionContextTypeB\x1b\n\x19\x66unction_argument_operandB\xf0\x01\n\"com.google.ads.googleads.v1.commonB\x15MatchingFunctionProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_matching__function__context__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_matching__function__operator__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_MATCHINGFUNCTION = _descriptor.Descriptor(
  name='MatchingFunction',
  full_name='google.ads.googleads.v1.common.MatchingFunction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='function_string', full_name='google.ads.googleads.v1.common.MatchingFunction.function_string', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v1.common.MatchingFunction.operator', index=1,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_operands', full_name='google.ads.googleads.v1.common.MatchingFunction.left_operands', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_operands', full_name='google.ads.googleads.v1.common.MatchingFunction.right_operands', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=609,
)


_OPERAND_CONSTANTOPERAND = _descriptor.Descriptor(
  name='ConstantOperand',
  full_name='google.ads.googleads.v1.common.Operand.ConstantOperand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_value', full_name='google.ads.googleads.v1.common.Operand.ConstantOperand.string_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='google.ads.googleads.v1.common.Operand.ConstantOperand.long_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_value', full_name='google.ads.googleads.v1.common.Operand.ConstantOperand.boolean_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='google.ads.googleads.v1.common.Operand.ConstantOperand.double_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='constant_operand_value', full_name='google.ads.googleads.v1.common.Operand.ConstantOperand.constant_operand_value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=988,
  serialized_end=1243,
)

_OPERAND_FEEDATTRIBUTEOPERAND = _descriptor.Descriptor(
  name='FeedAttributeOperand',
  full_name='google.ads.googleads.v1.common.Operand.FeedAttributeOperand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='google.ads.googleads.v1.common.Operand.FeedAttributeOperand.feed_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_attribute_id', full_name='google.ads.googleads.v1.common.Operand.FeedAttributeOperand.feed_attribute_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1245,
  serialized_end=1369,
)

_OPERAND_FUNCTIONOPERAND = _descriptor.Descriptor(
  name='FunctionOperand',
  full_name='google.ads.googleads.v1.common.Operand.FunctionOperand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matching_function', full_name='google.ads.googleads.v1.common.Operand.FunctionOperand.matching_function', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1371,
  serialized_end=1465,
)

_OPERAND_REQUESTCONTEXTOPERAND = _descriptor.Descriptor(
  name='RequestContextOperand',
  full_name='google.ads.googleads.v1.common.Operand.RequestContextOperand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='context_type', full_name='google.ads.googleads.v1.common.Operand.RequestContextOperand.context_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1468,
  serialized_end=1605,
)

_OPERAND = _descriptor.Descriptor(
  name='Operand',
  full_name='google.ads.googleads.v1.common.Operand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='constant_operand', full_name='google.ads.googleads.v1.common.Operand.constant_operand', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_attribute_operand', full_name='google.ads.googleads.v1.common.Operand.feed_attribute_operand', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_operand', full_name='google.ads.googleads.v1.common.Operand.function_operand', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_context_operand', full_name='google.ads.googleads.v1.common.Operand.request_context_operand', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OPERAND_CONSTANTOPERAND, _OPERAND_FEEDATTRIBUTEOPERAND, _OPERAND_FUNCTIONOPERAND, _OPERAND_REQUESTCONTEXTOPERAND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='function_argument_operand', full_name='google.ads.googleads.v1.common.Operand.function_argument_operand',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=612,
  serialized_end=1634,
)

_MATCHINGFUNCTION.fields_by_name['function_string'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MATCHINGFUNCTION.fields_by_name['operator'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_matching__function__operator__pb2._MATCHINGFUNCTIONOPERATORENUM_MATCHINGFUNCTIONOPERATOR
_MATCHINGFUNCTION.fields_by_name['left_operands'].message_type = _OPERAND
_MATCHINGFUNCTION.fields_by_name['right_operands'].message_type = _OPERAND
_OPERAND_CONSTANTOPERAND.fields_by_name['string_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_OPERAND_CONSTANTOPERAND.fields_by_name['long_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_OPERAND_CONSTANTOPERAND.fields_by_name['boolean_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_OPERAND_CONSTANTOPERAND.fields_by_name['double_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_OPERAND_CONSTANTOPERAND.containing_type = _OPERAND
_OPERAND_CONSTANTOPERAND.oneofs_by_name['constant_operand_value'].fields.append(
  _OPERAND_CONSTANTOPERAND.fields_by_name['string_value'])
_OPERAND_CONSTANTOPERAND.fields_by_name['string_value'].containing_oneof = _OPERAND_CONSTANTOPERAND.oneofs_by_name['constant_operand_value']
_OPERAND_CONSTANTOPERAND.oneofs_by_name['constant_operand_value'].fields.append(
  _OPERAND_CONSTANTOPERAND.fields_by_name['long_value'])
_OPERAND_CONSTANTOPERAND.fields_by_name['long_value'].containing_oneof = _OPERAND_CONSTANTOPERAND.oneofs_by_name['constant_operand_value']
_OPERAND_CONSTANTOPERAND.oneofs_by_name['constant_operand_value'].fields.append(
  _OPERAND_CONSTANTOPERAND.fields_by_name['boolean_value'])
_OPERAND_CONSTANTOPERAND.fields_by_name['boolean_value'].containing_oneof = _OPERAND_CONSTANTOPERAND.oneofs_by_name['constant_operand_value']
_OPERAND_CONSTANTOPERAND.oneofs_by_name['constant_operand_value'].fields.append(
  _OPERAND_CONSTANTOPERAND.fields_by_name['double_value'])
_OPERAND_CONSTANTOPERAND.fields_by_name['double_value'].containing_oneof = _OPERAND_CONSTANTOPERAND.oneofs_by_name['constant_operand_value']
_OPERAND_FEEDATTRIBUTEOPERAND.fields_by_name['feed_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_OPERAND_FEEDATTRIBUTEOPERAND.fields_by_name['feed_attribute_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_OPERAND_FEEDATTRIBUTEOPERAND.containing_type = _OPERAND
_OPERAND_FUNCTIONOPERAND.fields_by_name['matching_function'].message_type = _MATCHINGFUNCTION
_OPERAND_FUNCTIONOPERAND.containing_type = _OPERAND
_OPERAND_REQUESTCONTEXTOPERAND.fields_by_name['context_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_matching__function__context__type__pb2._MATCHINGFUNCTIONCONTEXTTYPEENUM_MATCHINGFUNCTIONCONTEXTTYPE
_OPERAND_REQUESTCONTEXTOPERAND.containing_type = _OPERAND
_OPERAND.fields_by_name['constant_operand'].message_type = _OPERAND_CONSTANTOPERAND
_OPERAND.fields_by_name['feed_attribute_operand'].message_type = _OPERAND_FEEDATTRIBUTEOPERAND
_OPERAND.fields_by_name['function_operand'].message_type = _OPERAND_FUNCTIONOPERAND
_OPERAND.fields_by_name['request_context_operand'].message_type = _OPERAND_REQUESTCONTEXTOPERAND
_OPERAND.oneofs_by_name['function_argument_operand'].fields.append(
  _OPERAND.fields_by_name['constant_operand'])
_OPERAND.fields_by_name['constant_operand'].containing_oneof = _OPERAND.oneofs_by_name['function_argument_operand']
_OPERAND.oneofs_by_name['function_argument_operand'].fields.append(
  _OPERAND.fields_by_name['feed_attribute_operand'])
_OPERAND.fields_by_name['feed_attribute_operand'].containing_oneof = _OPERAND.oneofs_by_name['function_argument_operand']
_OPERAND.oneofs_by_name['function_argument_operand'].fields.append(
  _OPERAND.fields_by_name['function_operand'])
_OPERAND.fields_by_name['function_operand'].containing_oneof = _OPERAND.oneofs_by_name['function_argument_operand']
_OPERAND.oneofs_by_name['function_argument_operand'].fields.append(
  _OPERAND.fields_by_name['request_context_operand'])
_OPERAND.fields_by_name['request_context_operand'].containing_oneof = _OPERAND.oneofs_by_name['function_argument_operand']
DESCRIPTOR.message_types_by_name['MatchingFunction'] = _MATCHINGFUNCTION
DESCRIPTOR.message_types_by_name['Operand'] = _OPERAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MatchingFunction = _reflection.GeneratedProtocolMessageType('MatchingFunction', (_message.Message,), dict(
  DESCRIPTOR = _MATCHINGFUNCTION,
  __module__ = 'google.ads.googleads_v1.proto.common.matching_function_pb2'
  ,
  __doc__ = """Matching function associated with a CustomerFeed, CampaignFeed, or
  AdGroupFeed. The matching function is used to filter the set of feed
  items selected.
  
  
  Attributes:
      function_string:
          String representation of the Function.  Examples: 1)
          IDENTITY(true) or IDENTITY(false). All or none feed items
          serve. 2) EQUALS(CONTEXT.DEVICE,"Mobile") 3)
          IN(FEED\_ITEM\_ID,{1000001,1000002,1000003}) 4)
          CONTAINS\_ANY(FeedAttribute[12345678,0],{"Mars cruise","Venus
          cruise"}) 5) AND(IN(FEED\_ITEM\_ID,{10001,10002}),EQUALS(CONTE
          XT.DEVICE,"Mobile")) See  https:
          //developers.google.com/adwords/api/docs/guides/feed-matching-
          functions  Note that because multiple strings may represent
          the same underlying function (whitespace and single versus
          double quotation marks, for example), the value returned may
          not be identical to the string sent in a mutate request.
      operator:
          Operator for a function.
      left_operands:
          The operands on the left hand side of the equation. This is
          also the operand to be used for single operand expressions
          such as NOT.
      right_operands:
          The operands on the right hand side of the equation.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.MatchingFunction)
  ))
_sym_db.RegisterMessage(MatchingFunction)

Operand = _reflection.GeneratedProtocolMessageType('Operand', (_message.Message,), dict(

  ConstantOperand = _reflection.GeneratedProtocolMessageType('ConstantOperand', (_message.Message,), dict(
    DESCRIPTOR = _OPERAND_CONSTANTOPERAND,
    __module__ = 'google.ads.googleads_v1.proto.common.matching_function_pb2'
    ,
    __doc__ = """A constant operand in a matching function.
    
    
    Attributes:
        constant_operand_value:
            Constant operand values. Required.
        string_value:
            String value of the operand if it is a string type.
        long_value:
            Int64 value of the operand if it is a int64 type.
        boolean_value:
            Boolean value of the operand if it is a boolean type.
        double_value:
            Double value of the operand if it is a double type.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.Operand.ConstantOperand)
    ))
  ,

  FeedAttributeOperand = _reflection.GeneratedProtocolMessageType('FeedAttributeOperand', (_message.Message,), dict(
    DESCRIPTOR = _OPERAND_FEEDATTRIBUTEOPERAND,
    __module__ = 'google.ads.googleads_v1.proto.common.matching_function_pb2'
    ,
    __doc__ = """A feed attribute operand in a matching function. Used to represent a
    feed attribute in feed.
    
    
    Attributes:
        feed_id:
            The associated feed. Required.
        feed_attribute_id:
            Id of the referenced feed attribute. Required.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.Operand.FeedAttributeOperand)
    ))
  ,

  FunctionOperand = _reflection.GeneratedProtocolMessageType('FunctionOperand', (_message.Message,), dict(
    DESCRIPTOR = _OPERAND_FUNCTIONOPERAND,
    __module__ = 'google.ads.googleads_v1.proto.common.matching_function_pb2'
    ,
    __doc__ = """A function operand in a matching function. Used to represent nested
    functions.
    
    
    Attributes:
        matching_function:
            The matching function held in this operand.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.Operand.FunctionOperand)
    ))
  ,

  RequestContextOperand = _reflection.GeneratedProtocolMessageType('RequestContextOperand', (_message.Message,), dict(
    DESCRIPTOR = _OPERAND_REQUESTCONTEXTOPERAND,
    __module__ = 'google.ads.googleads_v1.proto.common.matching_function_pb2'
    ,
    __doc__ = """An operand in a function referring to a value in the request context.
    
    
    Attributes:
        context_type:
            Type of value to be referred in the request context.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.Operand.RequestContextOperand)
    ))
  ,
  DESCRIPTOR = _OPERAND,
  __module__ = 'google.ads.googleads_v1.proto.common.matching_function_pb2'
  ,
  __doc__ = """An operand in a matching function.
  
  
  Attributes:
      function_argument_operand:
          Different operands that can be used in a matching function.
          Required.
      constant_operand:
          A constant operand in a matching function.
      feed_attribute_operand:
          This operand specifies a feed attribute in feed.
      function_operand:
          A function operand in a matching function. Used to represent
          nested functions.
      request_context_operand:
          An operand in a function referring to a value in the request
          context.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.Operand)
  ))
_sym_db.RegisterMessage(Operand)
_sym_db.RegisterMessage(Operand.ConstantOperand)
_sym_db.RegisterMessage(Operand.FeedAttributeOperand)
_sym_db.RegisterMessage(Operand.FunctionOperand)
_sym_db.RegisterMessage(Operand.RequestContextOperand)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import feed_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_feed__pb2
from google.ads.google_ads.v1.proto.services import feed_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_feed__service__pb2


class FeedServiceStub(object):
  """Proto file describing the Feed service.

  Service to manage feeds.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetFeed = channel.unary_unary(
        '/google.ads.googleads.v1.services.FeedService/GetFeed',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_feed__service__pb2.GetFeedRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_feed__pb2.Feed.FromString,
        )
    self.MutateFeeds = channel.unary_unary(
        '/google.ads.googleads.v1.services.FeedService/MutateFeeds',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_feed__service__pb2.MutateFeedsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_feed__service__pb2.MutateFeedsResponse.FromString,
        )


class FeedServiceServicer(object):
  """Proto file describing the Feed service.

  Service to manage feeds.
  """

  def GetFeed(self, request, context):
    """Returns the requested feed in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateFeeds(self, request, context):
    """Creates, updates, or removes feeds. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_FeedServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetFeed': grpc.unary_unary_rpc_method_handler(
          servicer.GetFeed,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_feed__service__pb2.GetFeedRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_feed__pb2.Feed.SerializeToString,
      ),
      'MutateFeeds': grpc.unary_unary_rpc_method_handler(
          servicer.MutateFeeds,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_feed__service__pb2.MutateFeedsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_feed__service__pb2.MutateFeedsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.FeedService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import ad_group_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__pb2
from google.ads.google_ads.v2.proto.services import ad_group_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2


class AdGroupServiceStub(object):
  """Proto file describing the Ad Group service.

  Service to manage ad groups.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetAdGroup = channel.unary_unary(
        '/google.ads.googleads.v2.services.AdGroupService/GetAdGroup',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.GetAdGroupRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__pb2.AdGroup.FromString,
        )
    self.MutateAdGroups = channel.unary_unary(
        '/google.ads.googleads.v2.services.AdGroupService/MutateAdGroups',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.MutateAdGroupsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.MutateAdGroupsResponse.FromString,
        )


class AdGroupServiceServicer(object):
  """Proto file describing the Ad Group service.

  Service to manage ad groups.
  """

  def GetAdGroup(self, request, context):
    """Returns the requested ad group in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateAdGroups(self, request, context):
    """Creates, updates, or removes ad groups. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdGroupServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetAdGroup': grpc.unary_unary_rpc_method_handler(
          servicer.GetAdGroup,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.GetAdGroupRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__pb2.AdGroup.SerializeToString,
      ),
      'MutateAdGroups': grpc.unary_unary_rpc_method_handler(
          servicer.MutateAdGroups,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.MutateAdGroupsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.MutateAdGroupsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.AdGroupService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/feed.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import affiliate_location_feed_relationship_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_affiliate__location__feed__relationship__type__pb2
from google.ads.google_ads.v2.proto.enums import feed_attribute_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__attribute__type__pb2
from google.ads.google_ads.v2.proto.enums import feed_origin_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__origin__pb2
from google.ads.google_ads.v2.proto.enums import feed_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/feed.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\tFeedProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n2google/ads/googleads_v2/proto/resources/feed.proto\x12!google.ads.googleads.v2.resources\x1aSgoogle/ads/googleads_v2/proto/enums/affiliate_location_feed_relationship_type.proto\x1a=google/ads/googleads_v2/proto/enums/feed_attribute_type.proto\x1a\x35google/ads/googleads_v2/proto/enums/feed_origin.proto\x1a\x35google/ads/googleads_v2/proto/enums/feed_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xba\x0b\n\x04\x46\x65\x65\x64\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x44\n\nattributes\x18\x04 \x03(\x0b\x32\x30.google.ads.googleads.v2.resources.FeedAttribute\x12W\n\x14\x61ttribute_operations\x18\t \x03(\x0b\x32\x39.google.ads.googleads.v2.resources.FeedAttributeOperation\x12H\n\x06origin\x18\x05 \x01(\x0e\x32\x38.google.ads.googleads.v2.enums.FeedOriginEnum.FeedOrigin\x12H\n\x06status\x18\x08 \x01(\x0e\x32\x38.google.ads.googleads.v2.enums.FeedStatusEnum.FeedStatus\x12\x63\n\x19places_location_feed_data\x18\x06 \x01(\x0b\x32>.google.ads.googleads.v2.resources.Feed.PlacesLocationFeedDataH\x00\x12i\n\x1c\x61\x66\x66iliate_location_feed_data\x18\x07 \x01(\x0b\x32\x41.google.ads.googleads.v2.resources.Feed.AffiliateLocationFeedDataH\x00\x1a\xc9\x04\n\x16PlacesLocationFeedData\x12\\\n\noauth_info\x18\x01 \x01(\x0b\x32H.google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.OAuthInfo\x12\x33\n\remail_address\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13\x62usiness_account_id\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x62usiness_name_filter\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x63\x61tegory_filters\x18\x05 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rlabel_filters\x18\x06 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x1a\xb7\x01\n\tOAuthInfo\x12\x31\n\x0bhttp_method\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10http_request_url\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19http_authorization_header\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x1a\xd7\x01\n\x19\x41\x66\x66iliateLocationFeedData\x12.\n\tchain_ids\x18\x01 \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x89\x01\n\x11relationship_type\x18\x02 \x01(\x0e\x32n.google.ads.googleads.v2.enums.AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeB\x1d\n\x1bsystem_feed_generation_data\"\xee\x01\n\rFeedAttribute\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12T\n\x04type\x18\x03 \x01(\x0e\x32\x46.google.ads.googleads.v2.enums.FeedAttributeTypeEnum.FeedAttributeType\x12\x32\n\x0eis_part_of_key\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xe2\x01\n\x16\x46\x65\x65\x64\x41ttributeOperation\x12T\n\x08operator\x18\x01 \x01(\x0e\x32\x42.google.ads.googleads.v2.resources.FeedAttributeOperation.Operator\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.google.ads.googleads.v2.resources.FeedAttribute\"1\n\x08Operator\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x07\n\x03\x41\x44\x44\x10\x02\x42\xf6\x01\n%com.google.ads.googleads.v2.resourcesB\tFeedProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_affiliate__location__feed__relationship__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__attribute__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__origin__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_FEEDATTRIBUTEOPERATION_OPERATOR = _descriptor.EnumDescriptor(
  name='Operator',
  full_name='google.ads.googleads.v2.resources.FeedAttributeOperation.Operator',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADD', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2297,
  serialized_end=2346,
)
_sym_db.RegisterEnumDescriptor(_FEEDATTRIBUTEOPERATION_OPERATOR)


_FEED_PLACESLOCATIONFEEDDATA_OAUTHINFO = _descriptor.Descriptor(
  name='OAuthInfo',
  full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.OAuthInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_method', full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.OAuthInfo.http_method', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_request_url', full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.OAuthInfo.http_request_url', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_authorization_header', full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.OAuthInfo.http_authorization_header', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1444,
  serialized_end=1627,
)

_FEED_PLACESLOCATIONFEEDDATA = _descriptor.Descriptor(
  name='PlacesLocationFeedData',
  full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='oauth_info', full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.oauth_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email_address', full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.email_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_account_id', full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.business_account_id', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_name_filter', full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.business_name_filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_filters', full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.category_filters', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_filters', full_name='google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.label_filters', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FEED_PLACESLOCATIONFEEDDATA_OAUTHINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1042,
  serialized_end=1627,
)

_FEED_AFFILIATELOCATIONFEEDDATA = _descriptor.Descriptor(
  name='AffiliateLocationFeedData',
  full_name='google.ads.googleads.v2.resources.Feed.AffiliateLocationFeedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_ids', full_name='google.ads.googleads.v2.resources.Feed.AffiliateLocationFeedData.chain_ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relationship_type', full_name='google.ads.googleads.v2.resources.Feed.AffiliateLocationFeedData.relationship_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1630,
  serialized_end=1845,
)

_FEED = _descriptor.Descriptor(
  name='Feed',
  full_name='google.ads.googleads.v2.resources.Feed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.Feed.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.Feed.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.Feed.name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='google.ads.googleads.v2.resources.Feed.attributes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_operations', full_name='google.ads.googleads.v2.resources.Feed.attribute_operations', index=4,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='google.ads.googleads.v2.resources.Feed.origin', index=5,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.Feed.status', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='places_location_feed_data', full_name='google.ads.googleads.v2.resources.Feed.places_location_feed_data', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='affiliate_location_feed_data', full_name='google.ads.googleads.v2.resources.Feed.affiliate_location_feed_data', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FEED_PLACESLOCATIONFEEDDATA, _FEED_AFFILIATELOCATIONFEEDDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='system_feed_generation_data', full_name='google.ads.googleads.v2.resources.Feed.system_feed_generation_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=410,
  serialized_end=1876,
)


_FEEDATTRIBUTE = _descriptor.Descriptor(
  name='FeedAttribute',
  full_name='google.ads.googleads.v2.resources.FeedAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.FeedAttribute.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.FeedAttribute.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.resources.FeedAttribute.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_part_of_key', full_name='google.ads.googleads.v2.resources.FeedAttribute.is_part_of_key', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1879,
  serialized_end=2117,
)


_FEEDATTRIBUTEOPERATION = _descriptor.Descriptor(
  name='FeedAttributeOperation',
  full_name='google.ads.googleads.v2.resources.FeedAttributeOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v2.resources.FeedAttributeOperation.operator', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v2.resources.FeedAttributeOperation.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDATTRIBUTEOPERATION_OPERATOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2120,
  serialized_end=2346,
)

_FEED_PLACESLOCATIONFEEDDATA_OAUTHINFO.fields_by_name['http_method'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEED_PLACESLOCATIONFEEDDATA_OAUTHINFO.fields_by_name['http_request_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEED_PLACESLOCATIONFEEDDATA_OAUTHINFO.fields_by_name['http_authorization_header'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEED_PLACESLOCATIONFEEDDATA_OAUTHINFO.containing_type = _FEED_PLACESLOCATIONFEEDDATA
_FEED_PLACESLOCATIONFEEDDATA.fields_by_name['oauth_info'].message_type = _FEED_PLACESLOCATIONFEEDDATA_OAUTHINFO
_FEED_PLACESLOCATIONFEEDDATA.fields_by_name['email_address'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEED_PLACESLOCATIONFEEDDATA.fields_by_name['business_account_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEED_PLACESLOCATIONFEEDDATA.fields_by_name['business_name_filter'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEED_PLACESLOCATIONFEEDDATA.fields_by_name['category_filters'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEED_PLACESLOCATIONFEEDDATA.fields_by_name['label_filters'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEED_PLACESLOCATIONFEEDDATA.containing_type = _FEED
_FEED_AFFILIATELOCATIONFEEDDATA.fields_by_name['chain_ids'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEED_AFFILIATELOCATIONFEEDDATA.fields_by_name['relationship_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_affiliate__location__feed__relationship__type__pb2._AFFILIATELOCATIONFEEDRELATIONSHIPTYPEENUM_AFFILIATELOCATIONFEEDRELATIONSHIPTYPE
_FEED_AFFILIATELOCATIONFEEDDATA.containing_type = _FEED
_FEED.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEED.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEED.fields_by_name['attributes'].message_type = _FEEDATTRIBUTE
_FEED.fields_by_name['attribute_operations'].message_type = _FEEDATTRIBUTEOPERATION
_FEED.fields_by_name['origin'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__origin__pb2._FEEDORIGINENUM_FEEDORIGIN
_FEED.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__status__pb2._FEEDSTATUSENUM_FEEDSTATUS
_FEED.fields_by_name['places_location_feed_data'].message_type = _FEED_PLACESLOCATIONFEEDDATA
_FEED.fields_by_name['affiliate_location_feed_data'].message_type = _FEED_AFFILIATELOCATIONFEEDDATA
_FEED.oneofs_by_name['system_feed_generation_data'].fields.append(
  _FEED.fields_by_name['places_location_feed_data'])
_FEED.fields_by_name['places_location_feed_data'].containing_oneof = _FEED.oneofs_by_name['system_feed_generation_data']
_FEED.oneofs_by_name['system_feed_generation_data'].fields.append(
  _FEED.fields_by_name['affiliate_location_feed_data'])
_FEED.fields_by_name['affiliate_location_feed_data'].containing_oneof = _FEED.oneofs_by_name['system_feed_generation_data']
_FEEDATTRIBUTE.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDATTRIBUTE.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDATTRIBUTE.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__attribute__type__pb2._FEEDATTRIBUTETYPEENUM_FEEDATTRIBUTETYPE
_FEEDATTRIBUTE.fields_by_name['is_part_of_key'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FEEDATTRIBUTEOPERATION.fields_by_name['operator'].enum_type = _FEEDATTRIBUTEOPERATION_OPERATOR
_FEEDATTRIBUTEOPERATION.fields_by_name['value'].message_type = _FEEDATTRIBUTE
_FEEDATTRIBUTEOPERATION_OPERATOR.containing_type = _FEEDATTRIBUTEOPERATION
DESCRIPTOR.message_types_by_name['Feed'] = _FEED
DESCRIPTOR.message_types_by_name['FeedAttribute'] = _FEEDATTRIBUTE
DESCRIPTOR.message_types_by_name['FeedAttributeOperation'] = _FEEDATTRIBUTEOPERATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Feed = _reflection.GeneratedProtocolMessageType('Feed', (_message.Message,), dict(

  PlacesLocationFeedData = _reflection.GeneratedProtocolMessageType('PlacesLocationFeedData', (_message.Message,), dict(

    OAuthInfo = _reflection.GeneratedProtocolMessageType('OAuthInfo', (_message.Message,), dict(
      DESCRIPTOR = _FEED_PLACESLOCATIONFEEDDATA_OAUTHINFO,
      __module__ = 'google.ads.googleads_v2.proto.resources.feed_pb2'
      ,
      __doc__ = """Data used for authorization using OAuth.
      
      
      Attributes:
          http_method:
              The HTTP method used to obtain authorization.
          http_request_url:
              The HTTP request URL used to obtain authorization.
          http_authorization_header:
              The HTTP authorization header used to obtain authorization.
      """,
      # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData.OAuthInfo)
      ))
    ,
    DESCRIPTOR = _FEED_PLACESLOCATIONFEEDDATA,
    __module__ = 'google.ads.googleads_v2.proto.resources.feed_pb2'
    ,
    __doc__ = """Data used to configure a location feed populated from Google My Business
    Locations.
    
    
    Attributes:
        oauth_info:
            Required authentication token (from OAuth API) for the email.
            This field can only be specified in a create request. All its
            subfields are not selectable.
        email_address:
            Email address of a Google My Business account or email address
            of a manager of the Google My Business account. Required.
        business_account_id:
            Plus page ID of the managed business whose locations should be
            used. If this field is not set, then all businesses accessible
            by the user (specified by email\_address) are used. This field
            is mutate-only and is not selectable.
        business_name_filter:
            Used to filter Google My Business listings by business name.
            If business\_name\_filter is set, only listings with a
            matching business name are candidates to be sync'd into
            FeedItems.
        category_filters:
            Used to filter Google My Business listings by categories. If
            entries exist in category\_filters, only listings that belong
            to any of the categories are candidates to be sync'd into
            FeedItems. If no entries exist in category\_filters, then all
            listings are candidates for syncing.
        label_filters:
            Used to filter Google My Business listings by labels. If
            entries exist in label\_filters, only listings that has any of
            the labels set are candidates to be synchronized into
            FeedItems. If no entries exist in label\_filters, then all
            listings are candidates for syncing.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Feed.PlacesLocationFeedData)
    ))
  ,

  AffiliateLocationFeedData = _reflection.GeneratedProtocolMessageType('AffiliateLocationFeedData', (_message.Message,), dict(
    DESCRIPTOR = _FEED_AFFILIATELOCATIONFEEDDATA,
    __module__ = 'google.ads.googleads_v2.proto.resources.feed_pb2'
    ,
    __doc__ = """Data used to configure an affiliate location feed populated with the
    specified chains.
    
    
    Attributes:
        chain_ids:
            The list of chains that the affiliate location feed will sync
            the locations from.
        relationship_type:
            The relationship the chains have with the advertiser.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Feed.AffiliateLocationFeedData)
    ))
  ,
  DESCRIPTOR = _FEED,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_pb2'
  ,
  __doc__ = """A feed.
  
  
  Attributes:
      resource_name:
          The resource name of the feed. Feed resource names have the
          form:  ``customers/{customer_id}/feeds/{feed_id}``
      id:
          The ID of the feed. This field is read-only.
      name:
          Name of the feed. Required.
      attributes:
          The Feed's attributes. Required on CREATE. Disallowed on
          UPDATE. Use attribute\_operations to add new attributes.
      attribute_operations:
          The list of operations changing the feed attributes.
          Attributes can only be added, not removed.
      origin:
          Specifies who manages the FeedAttributes for the Feed.
      status:
          Status of the feed. This field is read-only.
      system_feed_generation_data:
          The system data for the Feed. This data specifies information
          for generating the feed items of the system generated feed.
      places_location_feed_data:
          Data used to configure a location feed populated from Google
          My Business Locations.
      affiliate_location_feed_data:
          Data used to configure an affiliate location feed populated
          with the specified chains.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Feed)
  ))
_sym_db.RegisterMessage(Feed)
_sym_db.RegisterMessage(Feed.PlacesLocationFeedData)
_sym_db.RegisterMessage(Feed.PlacesLocationFeedData.OAuthInfo)
_sym_db.RegisterMessage(Feed.AffiliateLocationFeedData)

FeedAttribute = _reflection.GeneratedProtocolMessageType('FeedAttribute', (_message.Message,), dict(
  DESCRIPTOR = _FEEDATTRIBUTE,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_pb2'
  ,
  __doc__ = """FeedAttributes define the types of data expected to be present in a
  Feed. A single FeedAttribute specifies the expected type of the
  FeedItemAttributes with the same FeedAttributeId. Optionally, a
  FeedAttribute can be marked as being part of a FeedItem's unique key.
  
  
  Attributes:
      id:
          ID of the attribute.
      name:
          The name of the attribute. Required.
      type:
          Data type for feed attribute. Required.
      is_part_of_key:
          Indicates that data corresponding to this attribute is part of
          a FeedItem's unique key. It defaults to false if it is
          unspecified. Note that a unique key is not required in a
          Feed's schema, in which case the FeedItems must be referenced
          by their feed\_item\_id.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedAttribute)
  ))
_sym_db.RegisterMessage(FeedAttribute)

FeedAttributeOperation = _reflection.GeneratedProtocolMessageType('FeedAttributeOperation', (_message.Message,), dict(
  DESCRIPTOR = _FEEDATTRIBUTEOPERATION,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_pb2'
  ,
  __doc__ = """Operation to be performed on a feed attribute list in a mutate.
  
  
  Attributes:
      operator:
          Type of list operation to perform.
      value:
          The feed attribute being added to the list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedAttributeOperation)
  ))
_sym_db.RegisterMessage(FeedAttributeOperation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import campaign_criterion_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__criterion__pb2
from google.ads.google_ads.v2.proto.services import campaign_criterion_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2


class CampaignCriterionServiceStub(object):
  """Proto file describing the Campaign Criterion service.

  Service to manage campaign criteria.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCampaignCriterion = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignCriterionService/GetCampaignCriterion',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2.GetCampaignCriterionRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__criterion__pb2.CampaignCriterion.FromString,
        )
    self.MutateCampaignCriteria = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignCriterionService/MutateCampaignCriteria',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2.MutateCampaignCriteriaRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2.MutateCampaignCriteriaResponse.FromString,
        )


class CampaignCriterionServiceServicer(object):
  """Proto file describing the Campaign Criterion service.

  Service to manage campaign criteria.
  """

  def GetCampaignCriterion(self, request, context):
    """Returns the requested criterion in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCampaignCriteria(self, request, context):
    """Creates, updates, or removes criteria. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CampaignCriterionServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCampaignCriterion': grpc.unary_unary_rpc_method_handler(
          servicer.GetCampaignCriterion,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2.GetCampaignCriterionRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__criterion__pb2.CampaignCriterion.SerializeToString,
      ),
      'MutateCampaignCriteria': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCampaignCriteria,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2.MutateCampaignCriteriaRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2.MutateCampaignCriteriaResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.CampaignCriterionService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/function_parsing_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/function_parsing_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\031FunctionParsingErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\nAgoogle/ads/googleads_v1/proto/errors/function_parsing_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\x82\x03\n\x18\x46unctionParsingErrorEnum\"\xe5\x02\n\x14\x46unctionParsingError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x11\n\rNO_MORE_INPUT\x10\x02\x12\x16\n\x12\x45XPECTED_CHARACTER\x10\x03\x12\x18\n\x14UNEXPECTED_SEPARATOR\x10\x04\x12\x1a\n\x16UNMATCHED_LEFT_BRACKET\x10\x05\x12\x1b\n\x17UNMATCHED_RIGHT_BRACKET\x10\x06\x12\x1d\n\x19TOO_MANY_NESTED_FUNCTIONS\x10\x07\x12\x1e\n\x1aMISSING_RIGHT_HAND_OPERAND\x10\x08\x12\x19\n\x15INVALID_OPERATOR_NAME\x10\t\x12/\n+FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER\x10\n\x12\x0f\n\x0bNO_OPERANDS\x10\x0b\x12\x15\n\x11TOO_MANY_OPERANDS\x10\x0c\x42\xf4\x01\n\"com.google.ads.googleads.v1.errorsB\x19\x46unctionParsingErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_FUNCTIONPARSINGERRORENUM_FUNCTIONPARSINGERROR = _descriptor.EnumDescriptor(
  name='FunctionParsingError',
  full_name='google.ads.googleads.v1.errors.FunctionParsingErrorEnum.FunctionParsingError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_MORE_INPUT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_CHARACTER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNEXPECTED_SEPARATOR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNMATCHED_LEFT_BRACKET', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNMATCHED_RIGHT_BRACKET', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_NESTED_FUNCTIONS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_RIGHT_HAND_OPERAND', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_OPERATOR_NAME', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_OPERANDS', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_OPERANDS', index=12, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=161,
  serialized_end=518,
)
_sym_db.RegisterEnumDescriptor(_FUNCTIONPARSINGERRORENUM_FUNCTIONPARSINGERROR)


_FUNCTIONPARSINGERRORENUM = _descriptor.Descriptor(
  name='FunctionParsingErrorEnum',
  full_name='google.ads.googleads.v1.errors.FunctionParsingErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FUNCTIONPARSINGERRORENUM_FUNCTIONPARSINGERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=518,
)

_FUNCTIONPARSINGERRORENUM_FUNCTIONPARSINGERROR.containing_type = _FUNCTIONPARSINGERRORENUM
DESCRIPTOR.message_types_by_name['FunctionParsingErrorEnum'] = _FUNCTIONPARSINGERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FunctionParsingErrorEnum = _reflection.GeneratedProtocolMessageType('FunctionParsingErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _FUNCTIONPARSINGERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.function_parsing_error_pb2'
  ,
  __doc__ = """Container for enum describing possible function parsing errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.FunctionParsingErrorEnum)
  ))
_sym_db.RegisterMessage(FunctionParsingErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Accesses the google.ads.googleads.v1.services AdGroupCriterionService API."""

import pkg_resources
import warnings

from google.oauth2 import service_account
import google.api_core.gapic_v1.client_info
import google.api_core.gapic_v1.config
import google.api_core.gapic_v1.method
import google.api_core.grpc_helpers
import google.api_core.path_template

from google.ads.google_ads.v1.services import ad_group_criterion_service_client_config
from google.ads.google_ads.v1.services.transports import ad_group_criterion_service_grpc_transport
from google.ads.google_ads.v1.proto.services import ad_group_criterion_service_pb2

_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
    'google-ads', ).version


class AdGroupCriterionServiceClient(object):
    """Service to manage ad group criteria."""

    SERVICE_ADDRESS = 'googleads.googleapis.com:443'
    """The default address of the service."""

    # The name of the interface for this client. This is the key used to
    # find the method configuration in the client_config dictionary.
    _INTERFACE_NAME = 'google.ads.googleads.v1.services.AdGroupCriterionService'

    @classmethod
    def from_service_account_file(cls, filename, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
        file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            AdGroupCriterionServiceClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_file(
            filename)
        kwargs['credentials'] = credentials
        return cls(*args, **kwargs)

    from_service_account_json = from_service_account_file

    @classmethod
    def ad_group_criteria_path(cls, customer, ad_group_criteria):
        """Return a fully-qualified ad_group_criteria string."""
        return google.api_core.path_template.expand(
            'customers/{customer}/adGroupCriteria/{ad_group_criteria}',
            customer=customer,
            ad_group_criteria=ad_group_criteria,
        )

    def __init__(self,
                 transport=None,
                 channel=None,
                 credentials=None,
                 client_config=None,
                 client_info=None):
        """Constructor.

        Args:
            transport (Union[~.AdGroupCriterionServiceGrpcTransport,
                    Callable[[~.Credentials, type], ~.AdGroupCriterionServiceGrpcTransport]): A transport
                instance, responsible for actually making the API calls.
                The default transport uses the gRPC protocol.
                This argument may also be a callable which returns a
                transport instance. Callables will be sent the credentials
                as the first argument and the default transport class as
                the second argument.
            channel (grpc.Channel): DEPRECATED. A ``Channel`` instance
                through which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is mutually exclusive with providing a
                transport instance to ``transport``; doing so will raise
                an exception.
            client_config (dict): DEPRECATED. A dictionary of call options for
                each method. If not specified, the default configuration is used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Raise deprecation warnings for things we want to go away.
        if client_config is not None:
            warnings.warn(
                'The `client_config` argument is deprecated.',
                PendingDeprecationWarning,
                stacklevel=2)
        else:
            client_config = ad_group_criterion_service_client_config.config

        if channel:
            warnings.warn(
                'The `channel` argument is deprecated; use '
                '`transport` instead.',
                PendingDeprecationWarning,
                stacklevel=2)

        # Instantiate the transport.
        # The transport is responsible for handling serialization and
        # deserialization and actually sending data to the service.
        if transport:
            if callable(transport):
                self.transport = transport(
                    credentials=credentials,
                    default_class=ad_group_criterion_service_grpc_transport.
                    AdGroupCriterionServiceGrpcTransport,
                )
            else:
                if credentials:
                    raise ValueError(
                        'Received both a transport instance and '
                        'credentials; these are mutually exclusive.')
                self.transport = transport
        else:
            self.transport = ad_group_criterion_service_grpc_transport.AdGroupCriterionServiceGrpcTransport(
                address=self.SERVICE_ADDRESS,
                channel=channel,
                credentials=credentials,
            )

        if client_info is None:
            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
                gapic_version=_GAPIC_LIBRARY_VERSION, )
        else:
            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
        self._client_info = client_info

        # Parse out the default settings for retry and timeout for each RPC
        # from the client configuration.
        # (Ordinarily, these are the defaults specified in the `*_config.py`
        # file next to this one.)
        self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
            client_config['interfaces'][self._INTERFACE_NAME], )

        # Save a dictionary of cached API call functions.
        # These are the actual callables which invoke the proper
        # transport methods, wrapped with `wrap_method` to add retry,
        # timeout, and the like.
        self._inner_api_calls = {}

    # Service calls
    def get_ad_group_criterion(self,
                               resource_name,
                               retry=google.api_core.gapic_v1.method.DEFAULT,
                               timeout=google.api_core.gapic_v1.method.DEFAULT,
                               metadata=None):
        """
        Returns the requested criterion in full detail.

        Args:
            resource_name (str): The resource name of the criterion to fetch.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.ads.googleads_v1.types.AdGroupCriterion` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'get_ad_group_criterion' not in self._inner_api_calls:
            self._inner_api_calls[
                'get_ad_group_criterion'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.get_ad_group_criterion,
                    default_retry=self._method_configs['GetAdGroupCriterion'].
                    retry,
                    default_timeout=self.
                    _method_configs['GetAdGroupCriterion'].timeout,
                    client_info=self._client_info,
                )

        request = ad_group_criterion_service_pb2.GetAdGroupCriterionRequest(
            resource_name=resource_name, )
        return self._inner_api_calls['get_ad_group_criterion'](
            request, retry=retry, timeout=timeout, metadata=metadata)

    def mutate_ad_group_criteria(
            self,
            customer_id,
            operations,
            partial_failure=None,
            validate_only=None,
            retry=google.api_core.gapic_v1.method.DEFAULT,
            timeout=google.api_core.gapic_v1.method.DEFAULT,
            metadata=None):
        """
        Creates, updates, or removes criteria. Operation statuses are returned.

        Args:
            customer_id (str): ID of the customer whose criteria are being modified.
            operations (list[Union[dict, ~google.ads.googleads_v1.types.AdGroupCriterionOperation]]): The list of operations to perform on individual criteria.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.ads.googleads_v1.types.AdGroupCriterionOperation`
            partial_failure (bool): If true, successful operations will be carried out and invalid
                operations will return errors. If false, all operations will be carried
                out in one transaction if and only if they are all valid.
                Default is false.
            validate_only (bool): If true, the request is validated but not executed. Only errors are
                returned, not results.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.ads.googleads_v1.types.MutateAdGroupCriteriaResponse` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'mutate_ad_group_criteria' not in self._inner_api_calls:
            self._inner_api_calls[
                'mutate_ad_group_criteria'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.mutate_ad_group_criteria,
                    default_retry=self.
                    _method_configs['MutateAdGroupCriteria'].retry,
                    default_timeout=self.
                    _method_configs['MutateAdGroupCriteria'].timeout,
                    client_info=self._client_info,
                )

        request = ad_group_criterion_service_pb2.MutateAdGroupCriteriaRequest(
            customer_id=customer_id,
            operations=operations,
            partial_failure=partial_failure,
            validate_only=validate_only,
        )
        return self._inner_api_calls['mutate_ad_group_criteria'](
            request, retry=retry, timeout=timeout, metadata=metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/criterion_category_availability.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import advertising_channel_sub_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_advertising__channel__sub__type__pb2
from google.ads.google_ads.v1.proto.enums import advertising_channel_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_advertising__channel__type__pb2
from google.ads.google_ads.v1.proto.enums import criterion_category_channel_availability_mode_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_criterion__category__channel__availability__mode__pb2
from google.ads.google_ads.v1.proto.enums import criterion_category_locale_availability_mode_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_criterion__category__locale__availability__mode__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/criterion_category_availability.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\"CriterionCategoryAvailabilityProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\nJgoogle/ads/googleads_v1/proto/common/criterion_category_availability.proto\x12\x1egoogle.ads.googleads.v1.common\x1a\x46google/ads/googleads_v1/proto/enums/advertising_channel_sub_type.proto\x1a\x42google/ads/googleads_v1/proto/enums/advertising_channel_type.proto\x1aVgoogle/ads/googleads_v1/proto/enums/criterion_category_channel_availability_mode.proto\x1aUgoogle/ads/googleads_v1/proto/enums/criterion_category_locale_availability_mode.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xcb\x01\n\x1d\x43riterionCategoryAvailability\x12U\n\x07\x63hannel\x18\x01 \x01(\x0b\x32\x44.google.ads.googleads.v1.common.CriterionCategoryChannelAvailability\x12S\n\x06locale\x18\x02 \x03(\x0b\x32\x43.google.ads.googleads.v1.common.CriterionCategoryLocaleAvailability\"\xf0\x03\n$CriterionCategoryChannelAvailability\x12\x8f\x01\n\x11\x61vailability_mode\x18\x01 \x01(\x0e\x32t.google.ads.googleads.v1.enums.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode\x12r\n\x18\x61\x64vertising_channel_type\x18\x02 \x01(\x0e\x32P.google.ads.googleads.v1.enums.AdvertisingChannelTypeEnum.AdvertisingChannelType\x12|\n\x1c\x61\x64vertising_channel_sub_type\x18\x03 \x03(\x0e\x32V.google.ads.googleads.v1.enums.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType\x12\x44\n include_default_channel_sub_type\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x9e\x02\n#CriterionCategoryLocaleAvailability\x12\x8d\x01\n\x11\x61vailability_mode\x18\x01 \x01(\x0e\x32r.google.ads.googleads.v1.enums.CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode\x12\x32\n\x0c\x63ountry_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rlanguage_code\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xfd\x01\n\"com.google.ads.googleads.v1.commonB\"CriterionCategoryAvailabilityProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_advertising__channel__sub__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_advertising__channel__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_criterion__category__channel__availability__mode__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_criterion__category__locale__availability__mode__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CRITERIONCATEGORYAVAILABILITY = _descriptor.Descriptor(
  name='CriterionCategoryAvailability',
  full_name='google.ads.googleads.v1.common.CriterionCategoryAvailability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='google.ads.googleads.v1.common.CriterionCategoryAvailability.channel', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locale', full_name='google.ads.googleads.v1.common.CriterionCategoryAvailability.locale', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=691,
)


_CRITERIONCATEGORYCHANNELAVAILABILITY = _descriptor.Descriptor(
  name='CriterionCategoryChannelAvailability',
  full_name='google.ads.googleads.v1.common.CriterionCategoryChannelAvailability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='availability_mode', full_name='google.ads.googleads.v1.common.CriterionCategoryChannelAvailability.availability_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='advertising_channel_type', full_name='google.ads.googleads.v1.common.CriterionCategoryChannelAvailability.advertising_channel_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='advertising_channel_sub_type', full_name='google.ads.googleads.v1.common.CriterionCategoryChannelAvailability.advertising_channel_sub_type', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_default_channel_sub_type', full_name='google.ads.googleads.v1.common.CriterionCategoryChannelAvailability.include_default_channel_sub_type', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=694,
  serialized_end=1190,
)


_CRITERIONCATEGORYLOCALEAVAILABILITY = _descriptor.Descriptor(
  name='CriterionCategoryLocaleAvailability',
  full_name='google.ads.googleads.v1.common.CriterionCategoryLocaleAvailability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='availability_mode', full_name='google.ads.googleads.v1.common.CriterionCategoryLocaleAvailability.availability_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v1.common.CriterionCategoryLocaleAvailability.country_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='google.ads.googleads.v1.common.CriterionCategoryLocaleAvailability.language_code', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1193,
  serialized_end=1479,
)

_CRITERIONCATEGORYAVAILABILITY.fields_by_name['channel'].message_type = _CRITERIONCATEGORYCHANNELAVAILABILITY
_CRITERIONCATEGORYAVAILABILITY.fields_by_name['locale'].message_type = _CRITERIONCATEGORYLOCALEAVAILABILITY
_CRITERIONCATEGORYCHANNELAVAILABILITY.fields_by_name['availability_mode'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_criterion__category__channel__availability__mode__pb2._CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM_CRITERIONCATEGORYCHANNELAVAILABILITYMODE
_CRITERIONCATEGORYCHANNELAVAILABILITY.fields_by_name['advertising_channel_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_advertising__channel__type__pb2._ADVERTISINGCHANNELTYPEENUM_ADVERTISINGCHANNELTYPE
_CRITERIONCATEGORYCHANNELAVAILABILITY.fields_by_name['advertising_channel_sub_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_advertising__channel__sub__type__pb2._ADVERTISINGCHANNELSUBTYPEENUM_ADVERTISINGCHANNELSUBTYPE
_CRITERIONCATEGORYCHANNELAVAILABILITY.fields_by_name['include_default_channel_sub_type'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CRITERIONCATEGORYLOCALEAVAILABILITY.fields_by_name['availability_mode'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_criterion__category__locale__availability__mode__pb2._CRITERIONCATEGORYLOCALEAVAILABILITYMODEENUM_CRITERIONCATEGORYLOCALEAVAILABILITYMODE
_CRITERIONCATEGORYLOCALEAVAILABILITY.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CRITERIONCATEGORYLOCALEAVAILABILITY.fields_by_name['language_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['CriterionCategoryAvailability'] = _CRITERIONCATEGORYAVAILABILITY
DESCRIPTOR.message_types_by_name['CriterionCategoryChannelAvailability'] = _CRITERIONCATEGORYCHANNELAVAILABILITY
DESCRIPTOR.message_types_by_name['CriterionCategoryLocaleAvailability'] = _CRITERIONCATEGORYLOCALEAVAILABILITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CriterionCategoryAvailability = _reflection.GeneratedProtocolMessageType('CriterionCategoryAvailability', (_message.Message,), dict(
  DESCRIPTOR = _CRITERIONCATEGORYAVAILABILITY,
  __module__ = 'google.ads.googleads_v1.proto.common.criterion_category_availability_pb2'
  ,
  __doc__ = """Information of category availability, per advertising channel.
  
  
  Attributes:
      channel:
          Channel types and subtypes that are available to the category.
      locale:
          Locales that are available to the category for the channel.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CriterionCategoryAvailability)
  ))
_sym_db.RegisterMessage(CriterionCategoryAvailability)

CriterionCategoryChannelAvailability = _reflection.GeneratedProtocolMessageType('CriterionCategoryChannelAvailability', (_message.Message,), dict(
  DESCRIPTOR = _CRITERIONCATEGORYCHANNELAVAILABILITY,
  __module__ = 'google.ads.googleads_v1.proto.common.criterion_category_availability_pb2'
  ,
  __doc__ = """Information of advertising channel type and subtypes a category is
  available in.
  
  
  Attributes:
      availability_mode:
          Format of the channel availability. Can be ALL\_CHANNELS (the
          rest of the fields will not be set), CHANNEL\_TYPE (only
          advertising\_channel\_type type will be set, the category is
          available to all sub types under it) or
          CHANNEL\_TYPE\_AND\_SUBTYPES (advertising\_channel\_type,
          advertising\_channel\_sub\_type, and
          include\_default\_channel\_sub\_type will all be set).
      advertising_channel_type:
          Channel type the category is available to.
      advertising_channel_sub_type:
          Channel subtypes under the channel type the category is
          available to.
      include_default_channel_sub_type:
          Whether default channel sub type is included. For example,
          advertising\_channel\_type being DISPLAY and
          include\_default\_channel\_sub\_type being false means that
          the default display campaign where channel sub type is not set
          is not included in this availability configuration.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CriterionCategoryChannelAvailability)
  ))
_sym_db.RegisterMessage(CriterionCategoryChannelAvailability)

CriterionCategoryLocaleAvailability = _reflection.GeneratedProtocolMessageType('CriterionCategoryLocaleAvailability', (_message.Message,), dict(
  DESCRIPTOR = _CRITERIONCATEGORYLOCALEAVAILABILITY,
  __module__ = 'google.ads.googleads_v1.proto.common.criterion_category_availability_pb2'
  ,
  __doc__ = """Information about which locales a category is available in.
  
  
  Attributes:
      availability_mode:
          Format of the locale availability. Can be LAUNCHED\_TO\_ALL
          (both country and language will be empty), COUNTRY (only
          country will be set), LANGUAGE (only language wil be set),
          COUNTRY\_AND\_LANGUAGE (both country and language will be
          set).
      country_code:
          Code of the country.
      language_code:
          Code of the language.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CriterionCategoryLocaleAvailability)
  ))
_sym_db.RegisterMessage(CriterionCategoryLocaleAvailability)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/extension_feed_item.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v2.proto.common import extensions_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2
from google.ads.google_ads.v2.proto.enums import extension_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_extension__type__pb2
from google.ads.google_ads.v2.proto.enums import feed_item_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__status__pb2
from google.ads.google_ads.v2.proto.enums import feed_item_target_device_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__target__device__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/extension_feed_item.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\026ExtensionFeedItemProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\nAgoogle/ads/googleads_v2/proto/resources/extension_feed_item.proto\x12!google.ads.googleads.v2.resources\x1a\x33google/ads/googleads_v2/proto/common/criteria.proto\x1a\x35google/ads/googleads_v2/proto/common/extensions.proto\x1a\x38google/ads/googleads_v2/proto/enums/extension_type.proto\x1a:google/ads/googleads_v2/proto/enums/feed_item_status.proto\x1a\x41google/ads/googleads_v2/proto/enums/feed_item_target_device.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xc7\r\n\x11\x45xtensionFeedItem\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n\x0e\x65xtension_type\x18\r \x01(\x0e\x32>.google.ads.googleads.v2.enums.ExtensionTypeEnum.ExtensionType\x12\x35\n\x0fstart_date_time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rend_date_time\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x44\n\x0c\x61\x64_schedules\x18\x10 \x03(\x0b\x32..google.ads.googleads.v2.common.AdScheduleInfo\x12\\\n\x06\x64\x65vice\x18\x11 \x01(\x0e\x32L.google.ads.googleads.v2.enums.FeedItemTargetDeviceEnum.FeedItemTargetDevice\x12\x42\n\x1ctargeted_geo_target_constant\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x10targeted_keyword\x18\x16 \x01(\x0b\x32+.google.ads.googleads.v2.common.KeywordInfo\x12P\n\x06status\x18\x04 \x01(\x0e\x32@.google.ads.googleads.v2.enums.FeedItemStatusEnum.FeedItemStatus\x12N\n\x12sitelink_feed_item\x18\x02 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.SitelinkFeedItemH\x00\x12\x61\n\x1cstructured_snippet_feed_item\x18\x03 \x01(\x0b\x32\x39.google.ads.googleads.v2.common.StructuredSnippetFeedItemH\x00\x12\x44\n\rapp_feed_item\x18\x07 \x01(\x0b\x32+.google.ads.googleads.v2.common.AppFeedItemH\x00\x12\x46\n\x0e\x63\x61ll_feed_item\x18\x08 \x01(\x0b\x32,.google.ads.googleads.v2.common.CallFeedItemH\x00\x12L\n\x11\x63\x61llout_feed_item\x18\t \x01(\x0b\x32/.google.ads.googleads.v2.common.CalloutFeedItemH\x00\x12U\n\x16text_message_feed_item\x18\n \x01(\x0b\x32\x33.google.ads.googleads.v2.common.TextMessageFeedItemH\x00\x12H\n\x0fprice_feed_item\x18\x0b \x01(\x0b\x32-.google.ads.googleads.v2.common.PriceFeedItemH\x00\x12P\n\x13promotion_feed_item\x18\x0c \x01(\x0b\x32\x31.google.ads.googleads.v2.common.PromotionFeedItemH\x00\x12N\n\x12location_feed_item\x18\x0e \x01(\x0b\x32\x30.google.ads.googleads.v2.common.LocationFeedItemH\x00\x12\x61\n\x1c\x61\x66\x66iliate_location_feed_item\x18\x0f \x01(\x0b\x32\x39.google.ads.googleads.v2.common.AffiliateLocationFeedItemH\x00\x12W\n\x17hotel_callout_feed_item\x18\x17 \x01(\x0b\x32\x34.google.ads.googleads.v2.common.HotelCalloutFeedItemH\x00\x12\x39\n\x11targeted_campaign\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x01\x12\x39\n\x11targeted_ad_group\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x01\x42\x0b\n\textensionB\x1c\n\x1aserving_resource_targetingB\x83\x02\n%com.google.ads.googleads.v2.resourcesB\x16\x45xtensionFeedItemProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_extension__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__target__device__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_EXTENSIONFEEDITEM = _descriptor.Descriptor(
  name='ExtensionFeedItem',
  full_name='google.ads.googleads.v2.resources.ExtensionFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.id', index=1,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension_type', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.extension_type', index=2,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.start_date_time', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.end_date_time', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_schedules', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.ad_schedules', index=5,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.device', index=6,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targeted_geo_target_constant', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.targeted_geo_target_constant', index=7,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targeted_keyword', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.targeted_keyword', index=8,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.status', index=9,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sitelink_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.sitelink_feed_item', index=10,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='structured_snippet_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.structured_snippet_feed_item', index=11,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.app_feed_item', index=12,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.call_feed_item', index=13,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='callout_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.callout_feed_item', index=14,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_message_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.text_message_feed_item', index=15,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.price_feed_item', index=16,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='promotion_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.promotion_feed_item', index=17,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.location_feed_item', index=18,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='affiliate_location_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.affiliate_location_feed_item', index=19,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_callout_feed_item', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.hotel_callout_feed_item', index=20,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targeted_campaign', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.targeted_campaign', index=21,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targeted_ad_group', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.targeted_ad_group', index=22,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='extension', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.extension',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='serving_resource_targeting', full_name='google.ads.googleads.v2.resources.ExtensionFeedItem.serving_resource_targeting',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=460,
  serialized_end=2195,
)

_EXTENSIONFEEDITEM.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_EXTENSIONFEEDITEM.fields_by_name['extension_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_extension__type__pb2._EXTENSIONTYPEENUM_EXTENSIONTYPE
_EXTENSIONFEEDITEM.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXTENSIONFEEDITEM.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXTENSIONFEEDITEM.fields_by_name['ad_schedules'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._ADSCHEDULEINFO
_EXTENSIONFEEDITEM.fields_by_name['device'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__target__device__pb2._FEEDITEMTARGETDEVICEENUM_FEEDITEMTARGETDEVICE
_EXTENSIONFEEDITEM.fields_by_name['targeted_geo_target_constant'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXTENSIONFEEDITEM.fields_by_name['targeted_keyword'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._KEYWORDINFO
_EXTENSIONFEEDITEM.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__status__pb2._FEEDITEMSTATUSENUM_FEEDITEMSTATUS
_EXTENSIONFEEDITEM.fields_by_name['sitelink_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._SITELINKFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['structured_snippet_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._STRUCTUREDSNIPPETFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['app_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._APPFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['call_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._CALLFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['callout_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._CALLOUTFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['text_message_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._TEXTMESSAGEFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['price_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._PRICEFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['promotion_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._PROMOTIONFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['location_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._LOCATIONFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['affiliate_location_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._AFFILIATELOCATIONFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['hotel_callout_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_extensions__pb2._HOTELCALLOUTFEEDITEM
_EXTENSIONFEEDITEM.fields_by_name['targeted_campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXTENSIONFEEDITEM.fields_by_name['targeted_ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['sitelink_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['sitelink_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['structured_snippet_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['structured_snippet_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['app_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['app_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['call_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['call_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['callout_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['callout_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['text_message_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['text_message_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['price_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['price_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['promotion_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['promotion_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['location_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['location_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['affiliate_location_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['affiliate_location_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['extension'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['hotel_callout_feed_item'])
_EXTENSIONFEEDITEM.fields_by_name['hotel_callout_feed_item'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['extension']
_EXTENSIONFEEDITEM.oneofs_by_name['serving_resource_targeting'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['targeted_campaign'])
_EXTENSIONFEEDITEM.fields_by_name['targeted_campaign'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['serving_resource_targeting']
_EXTENSIONFEEDITEM.oneofs_by_name['serving_resource_targeting'].fields.append(
  _EXTENSIONFEEDITEM.fields_by_name['targeted_ad_group'])
_EXTENSIONFEEDITEM.fields_by_name['targeted_ad_group'].containing_oneof = _EXTENSIONFEEDITEM.oneofs_by_name['serving_resource_targeting']
DESCRIPTOR.message_types_by_name['ExtensionFeedItem'] = _EXTENSIONFEEDITEM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtensionFeedItem = _reflection.GeneratedProtocolMessageType('ExtensionFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _EXTENSIONFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.resources.extension_feed_item_pb2'
  ,
  __doc__ = """An extension feed item.
  
  
  Attributes:
      resource_name:
          The resource name of the extension feed item. Extension feed
          item resource names have the form:
          ``customers/{customer_id}/extensionFeedItems/{feed_item_id}``
      id:
          The ID of this feed item. Read-only.
      extension_type:
          The extension type of the extension feed item. This field is
          read-only.
      start_date_time:
          Start time in which this feed item is effective and can begin
          serving. The time is in the customer's time zone. The format
          is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or
          "2018-02-01 14:34:30"
      end_date_time:
          End time in which this feed item is no longer effective and
          will stop serving. The time is in the customer's time zone.
          The format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05
          09:15:00" or "2018-02-01 14:34:30"
      ad_schedules:
          List of non-overlapping schedules specifying all time
          intervals for which the feed item may serve. There can be a
          maximum of 6 schedules per day.
      device:
          The targeted device.
      targeted_geo_target_constant:
          The targeted geo target constant.
      targeted_keyword:
          The targeted keyword.
      status:
          Status of the feed item. This field is read-only.
      extension:
          Extension type.
      sitelink_feed_item:
          Sitelink extension.
      structured_snippet_feed_item:
          Structured snippet extension.
      app_feed_item:
          App extension.
      call_feed_item:
          Call extension.
      callout_feed_item:
          Callout extension.
      text_message_feed_item:
          Text message extension.
      price_feed_item:
          Price extension.
      promotion_feed_item:
          Promotion extension.
      location_feed_item:
          Location extension. Locations are synced from a GMB account
          into a feed. This field is read-only.
      affiliate_location_feed_item:
          Affiliate location extension. Feed locations are populated by
          Google Ads based on a chain ID. This field is read-only.
      hotel_callout_feed_item:
          Hotel Callout extension.
      serving_resource_targeting:
          Targeting at either the campaign or ad group level. Feed items
          that target a campaign or ad group will only serve with that
          resource.
      targeted_campaign:
          The targeted campaign.
      targeted_ad_group:
          The targeted ad group.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.ExtensionFeedItem)
  ))
_sym_db.RegisterMessage(ExtensionFeedItem)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
